{% csrf_token %}
{% include "django_libs/partials/form_non_field_errors.html" %}
{% for field in form %}
    {% include "django_libs/partials/form_field.html" with hide_label=hide_label %}
{% endfor %}