"""Default settings for the CustomRaven404CatchMiddleware"""
RAVEN_IGNORABLE_USER_AGENTS = [
    r'AhrefsBot',
    r'EasouSpider',
    r'FacebookBot',
    r'Feedfetcher-Google',
    r'Googlebot',
    r'Mail.RU_Bot',
    r'Test Certificate Info',
    r'Twitterbot',
    r'Yahoo! Slurp',
    r'YandexBot',
    r'bingbot',
]
